@@ -24,14 +24,14 @@ function _aws_cdk_aws_wisdom_CfnKnowledgeBaseProps(p) {
         require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_wisdom_CfnAssistant(p) {
-}
-function _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty(p) {
-}
 function _aws_cdk_aws_wisdom_CfnAssistantAssociation(p) {
 }
 function _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty(p) {
 }
+function _aws_cdk_aws_wisdom_CfnAssistant(p) {
+}
+function _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty(p) {
+}
 function _aws_cdk_aws_wisdom_CfnKnowledgeBase(p) {
 }
 function _aws_cdk_aws_wisdom_CfnKnowledgeBase_RenderingConfigurationProperty(p) {
@@ -57,5 +57,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_wisdom_CfnAssistantAssociationProps, _aws_cdk_aws_wisdom_CfnAssistantProps, _aws_cdk_aws_wisdom_CfnKnowledgeBaseProps, _aws_cdk_aws_wisdom_CfnAssistant, _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty, _aws_cdk_aws_wisdom_CfnAssistantAssociation, _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase, _aws_cdk_aws_wisdom_CfnKnowledgeBase_RenderingConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_ServerSideEncryptionConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_AppIntegrationsConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_SourceConfigurationProperty };
+module.exports = { print, _aws_cdk_aws_wisdom_CfnAssistantAssociationProps, _aws_cdk_aws_wisdom_CfnAssistantProps, _aws_cdk_aws_wisdom_CfnKnowledgeBaseProps, _aws_cdk_aws_wisdom_CfnAssistantAssociation, _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty, _aws_cdk_aws_wisdom_CfnAssistant, _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase, _aws_cdk_aws_wisdom_CfnKnowledgeBase_RenderingConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_ServerSideEncryptionConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_AppIntegrationsConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_SourceConfigurationProperty };
 module.exports.DeprecationError = DeprecationError;
